%global python3_abiflags	 %(/usr/bin/python3-config --abiflags)
%define toplev_dirname		%{name}_%(echo "%{version}"|tr \. _)
%define	libname			%mklibname %{name} %{version}
%define	devname			%mklibname %{name} -d
%define	devnamestatic		%mklibname %{name} -d -s
%define libnamempi		%mklibname %{name}-openmpi %{version}
%define devnamempi		%mklibname %{name}-openmpi -d
%define libnamempich		%mklibname %{name}-mpich %{version}
%define devnamempich		%mklibname %{name}-mpich -d
%define libnamegraphmpich	%mklibname %{name}-graph-mpich %{version}
%define libnamepy3		%mklibname %{name}-python3 _%{version}
%define devnamepy3		%mklibname %{name}-python3 -d
%define libnamempipy		%mklibname %{name}-mpi-python %{version}
%define devnamempipy		%mklibname %{name}-mpi-python -d
%define libnamempichpy		%mklibname %{name}-mpich-python %{version}
%define libnamegraphmpi		%mklibname %{name}-graph-mpi %{version}
%define devnamegraphmpi		%mklibname %{name}-graph-mpi -d

# Conditionals from Fedora
%ifarch ppc64le
  %bcond_with mpich
%else
  %bcond_without mpich
%endif

%ifarch s390 s390x ppc64le
# No OpenMPI support on these arches
  %bcond_with openmpi
%else
  %bcond_without openmpi
%endif

%ifnarch %{ix86} x86_64 %{arm} ppc64 ppc64le aarch64
  %bcond_with context
%else
  %bcond_without context
%endif

################
Name:		boost
Summary:	The free peer-reviewed portable C++ source libraries
Version:	1.60.0
Release:	%mkrel 6
License:	Boost
URL:		http://boost.org/
Group:		Development/C++
Source0:	http://downloads.sourceforge.net/%{name}/%{toplev_dirname}.tar.bz2
Source1:	libboost_thread.so

BuildRequires:	bzip2-devel
BuildRequires:	libicu-devel 
BuildRequires:	libstdc++-devel
BuildRequires:	m4
BuildRequires:	pkgconfig(python)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(zlib)

# https://svn.boost.org/trac/boost/ticket/6150
Patch4:		boost-1.50.0-fix-non-utf8-files.patch

# Add a manual page for bjam, based on the on-line documentation:
# http://www.boost.org/boost-build2/doc/html/bbv2/overview.html
Patch5:		boost-1.48.0-add-bjam-man-page.patch

# https://bugzilla.redhat.com/show_bug.cgi?id=828856
# https://bugzilla.redhat.com/show_bug.cgi?id=828857
# https://svn.boost.org/trac/boost/ticket/6701
Patch15:	boost-1.58.0-pool.patch

# https://svn.boost.org/trac/boost/ticket/5637
Patch25:	boost-1.57.0-mpl-print.patch

# https://svn.boost.org/trac/boost/ticket/8870
Patch36:	boost-1.57.0-spirit-unused_typedef.patch

# https://svn.boost.org/trac/boost/ticket/9038
Patch51:	boost-1.58.0-pool-test_linking.patch

# https://bugzilla.redhat.com/show_bug.cgi?id=1102667
Patch61:	boost-1.57.0-python-libpython_dep.patch
Patch62:	boost-1.57.0-python-abi_letters.patch
Patch63:	boost-1.55.0-python-test-PyImport_AppendInittab.patch

# https://bugzilla.redhat.com/show_bug.cgi?id=1190039
Patch65:	boost-1.57.0-build-optflags.patch

# Prevent gcc.jam from setting -m32 or -m64.
Patch68:	boost-1.58.0-address-model.patch

%bcond_with tests
%bcond_with docs_generated

%define boostlibs atomic chrono container context coroutine date_time filesystem graph iostreams locale log math prg_exec_monitor program_options python random regex serialization signals system thread timer type_erasure unit_test_framework wave wserialization
# (Anssi 01/2010) dashes are converted to underscores for macros ($lib2);
# The sed script adds _ when library name ends in number.
%{expand:%(for lib in %boostlibs; do lib2=${lib/-/_}; cat <<EOF
%%global libname$lib2 %%mklibname boost_$(echo $lib | sed 's,[0-9]$,&_,') %{version}
%%package -n %%{libname$lib2}
Summary:	Boost $lib shared library
# no one should require this, but provided anyway for maximum compatibility:
Provides:	boost = %version-%release
Group:		System/Libraries
EOF
done)}
# (Anssi 01/2010) splitted expand contents due to rpm bug failing build,
# triggered by a too long expanded string.
%{expand:%(for lib in %boostlibs; do lib2=${lib/-/_}; cat <<EOF
%%description -n %%{libname$lib2}
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains the shared library needed for
running programs dynamically linked against Boost $lib.
EOF
done)}
%{expand:%(for lib in %boostlibs; do lib2=${lib/-/_}; cat <<EOF
%%files -n %%{libname$lib2}
%%doc LICENSE_1_0.txt
%{_libdir}/libboost_$lib*.so.%{version}
EOF
done)}

%description
Boost provides free peer-reviewed portable C++ source libraries.  The
emphasis is on libraries which work well with the C++ Standard
Library, in the hopes of establishing "existing practice" for
extensions and providing reference implementations so that the Boost
libraries are suitable for eventual standardization. (Some of the
libraries have already been included in the C++ 2011 standard and
others have been proposed to the C++ Standards Committee for inclusion
in future standards.)

%package -n %{libnamepy3}
Summary:	Run-Time component of boost python library for Python 3
Group:		System/Libraries

%description -n %{libnamepy3}
The Boost Python Library is a framework for interfacing Python and
C++. It allows you to quickly and seamlessly expose C++ classes,
functions and objects to Python, and vice versa, using no special
tools -- just your C++ compiler.  This package contains run-time
support for Boost Python Library compiled for Python 3.

%package -n	%{devname}
Summary:	The libraries and headers needed for Boost development
Group:		Development/C++
Requires:	%{expand:%(for lib in %boostlibs; do echo -n "%%{libname${lib/-/_}} = %{version}-%{release} "; done)}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
# Required because thread linker script stops auto generation of devel(...) provide
Provides:	devel(libboost_thread%([ "%{?_lib}" = "lib64" ] && echo "(64bit)")) = %{version}-%{release}
Obsoletes:	%{_lib}boost_thread-devel < 1.59.0-5
Conflicts:	%{_lib}boost_thread-devel < 1.59.0-5

%description -n	%{devname}
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains headers and shared library
symlinks needed for Boost development.

%package -n	%{devnamestatic}
Summary:	The Boost C++ static development libraries
Group:		System/Libraries
Requires:	%{name}-devel = %{version}-%{release}
Provides:	boost-devel-static = %{version}-%{release}

%description -n	%{devnamestatic}
Static Boost C++ libraries.

%package	devel-doc
Summary:	Documentation for developers using Boost
Group:		Development/C++
BuildArch:	noarch

%description devel-doc
Boost is a collection of free peer-reviewed portable C++ source
libraries. The emphasis is on libraries which work well with the C++
Standard Library. This package contains documentation needed for Boost
development.

%package	examples
Summary:	Source examples for the Boost C++ libraries
Group:		Documentation
BuildArch:	noarch
Requires:	%{name}-devel = %{version}-%{release}

%description	examples
This package contains example source files distributed with boost.

%if %{with openmpi}

%package -n	%{libnamempi}
Summary:	Run-Time component of Boost.MPI library
Group:		System/Libraries
BuildRequires:	openmpi-devel
Requires:	%{_lib}boost_serialization%{version} = %{version}-%{release}

%description -n	%{libnamempi}
Run-Time support for Boost.MPI-OpenMPI, a library providing a clean C++
API over the OpenMPI implementation of MPI.

%package -n	%{devnamempi}
Summary:	Shared library symbolic links for Boost.MPI
Group:		System/Libraries
Requires:	%{name}-devel = %{version}-%{release}
Requires:	%{libnamempi} = %{version}-%{release}
Requires:	%{libnamempipy} = %{version}-%{release}
Requires:	%{libnamegraphmpi} = %{version}-%{release}

%description -n	%{devnamempi}
Devel package for Boost.MPI-OpenMPI, a library providing a clean C++
API over the OpenMPI implementation of MPI.

%package -n	%{libnamempipy}
Summary:	Python run-time component of Boost.MPI library
Group:		System/Libraries
Requires:	%{libnamempi} = %{version}-%{release}
Requires:	%{_lib}boost_python%{version} = %{version}-%{release}
Requires:	%{_lib}boost_serialization%{version} = %{version}-%{release}

%description -n	%{libnamempipy}
Python support for Boost.MPI-OpenMPI, a library providing a clean C++
API over the OpenMPI implementation of MPI.

%package -n	%{libnamegraphmpi}
Summary:	Run-Time component of parallel boost graph library
Group:		System/Libraries
Requires:	%{libnamempi} = %{version}-%{release}
Requires:	%{_lib}boost_serialization%{version} = %{version}-%{release}

%description -n	%{libnamegraphmpi}
Run-Time support for the Parallel BGL graph library.  The interface and
graph components are generic, in the same sense as the the Standard
Template Library (STL).  The libraries in this package use OpenMPI
back-end to do the parallel work.

%endif

%if %{with mpich}

%package -n	%{libnamempich}
Summary:	Run-Time component of Boost.MPI library
Group:		System/Libraries
Requires:	%{_lib}boost_serialization%{version} = %{version}-%{release}
Provides:	%{_lib}boost-mpich2 = %{version}-%{release}

%description -n	%{libnamempich}
Run-Time support for Boost.MPI-MPICH, a library providing a clean C++
API over the MPICH implementation of MPI.

%package -n	%{devnamempich}
Summary:	Shared library symbolic links for Boost.MPI
Group:		System/Libraries
Requires:	%{name}-devel = %{version}-%{release}
Requires:	%{libnamempich} = %{version}-%{release}
Requires:	%{libnamempichpy} = %{version}-%{release}
Requires:	%{libnamegraphmpich} = %{version}-%{release}
Provides:	boost-mpich2-devel = %{version}-%{release}

%description -n	%{devnamempich}
Devel package for Boost.MPI-MPICH, a library providing a clean C++
API over the MPICH implementation of MPI.

%package -n	%{libnamempichpy}
Summary:	Python run-time component of Boost.MPI library
Group:		System/Libraries
Requires:	%{libnamempich} = %{version}-%{release}
Requires:	%{_lib}boost_python%{version} = %{version}-%{release}
Requires:	%{_lib}boost_serialization%{version} = %{version}-%{release}
Provides:	boost-mpich2-python = %{version}-%{release}

%description -n %{libnamempichpy}
Python support for Boost.MPI-MPICH, a library providing a clean C++
API over the MPICH implementation of MPI.

%package -n	%{libnamegraphmpich}
Summary:	Run-Time component of parallel boost graph library
Group:		System/Libraries
Requires:	%{libnamempich} = %{version}-%{release}
Requires:	%{_lib}boost_serialization%{version} = %{version}-%{release}
Provides:	boost-graph-mpich2 = %{version}-%{release}

%description -n	%{libnamegraphmpich}
Run-Time support for the Parallel BGL graph library.  The interface and
graph components are generic, in the same sense as the the Standard
Template Library (STL).  This libraries in this package use MPICH
back-end to do the parallel work.

%endif

%package	build
Summary:	Cross platform build system for C++ projects
Group:		Development/Tools
Requires:	boost-jam
BuildArch:	noarch

%description	build
Boost.Build is an easy way to build C++ projects, everywhere. You name
your pieces of executable and libraries and list their sources.  Boost.Build
takes care about compiling your sources with the right options,
creating static and shared libraries, making pieces of executable, and other
chores -- whether you're using GCC, MSVC, or a dozen more supported
C++ compilers -- on Windows, OSX, Linux and commercial UNIX systems.

%package	doctools
Summary:	Tools for working with Boost documentation
Group:		Publishing
Requires:	docbook-dtds
Requires:	docbook-style-xsl

%description	doctools

Tools for working with Boost documentation in BoostBook or QuickBook format.

%package	bjam
Summary:	A low-level build tool
Group:		Development/Tools
Obsoletes:	%{name}-jam < 3.1.19
Provides:	%{name}-jam = %{version}-%{release}

%description	bjam
Boost.Jam (BJam) is the low-level build engine tool for Boost.Build.
Historically, Boost.Jam is based on on FTJam and on Perforce Jam but has grown
a number of significant features and is now developed independently

%prep
%setup -q -n %{toplev_dirname}
%patch4 -p1
%patch5 -p1
%patch15 -p0
%patch25 -p1
%patch36 -p1
%patch51 -p1
%patch61 -p1
%patch62 -p1
%patch63 -p1
%patch65 -p1
%patch68 -p1

# Build section adapted from Fedora
%build
: PYTHON2_VERSION=%{python2_version}
: PYTHON3_VERSION=%{python3_version}
: PYTHON3_ABIFLAGS=%{python3_abiflags}

# There are many strict aliasing warnings, and it's not feasible to go
# through them all at this time.
# There are also lots of noisy but harmless unused local typedef warnings.
export RPM_OPT_FLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -Wno-unused-local-typedefs"

cat > ./tools/build/src/user-config.jam << "EOF"
import os ;
local RPM_OPT_FLAGS = [ os.environ RPM_OPT_FLAGS ] ;

using gcc : : : <compileflags>$(RPM_OPT_FLAGS) ;
%if %{with openmpi} || %{with mpich}
using mpi ;
%endif
using python : %{python2_version} : /usr/bin/python2 : /usr/include/python%{python2_version} : : : : ;
using python : %{python3_version} : /usr/bin/python3 : /usr/include/python%{python3_version}%{python3_abiflags} : : : : %{python3_abiflags} ;
EOF
./bootstrap.sh --with-toolset=gcc --with-icu --prefix=%{_prefix} --libdir=%{_libdir}

# N.B. When we build the following with PCH, parts of boost (math
# library in particular) end up being built second time during
# installation.  Unsure why that is, but all sub-builds need to be
# built with pch=off to avoid this.
#
# The "python=2.*" bit tells jam that we want to _also_ build 2.*, not
# just 3.*.  When omitted, it just builds for python 3 twice, once
# calling the library libboost_python and once libboost_python3.  I
# assume this is for backward compatibility for apps that are used to
# linking against -lboost_python, for when 2->3 transition is
# eventually done.

echo ============================= build serial ==================
./b2 -d+2 -q %{?_smp_mflags} \
	--without-mpi \
	--without-graph_parallel \
	--build-dir=serial \
%if !%{with context}
	--without-context \
	--without-coroutine \
%endif
	variant=release \
	threading=multi \
	debug-symbols=on \
	pch=off \
	python=%{python2_version} \
	stage

# See libs/thread/build/Jamfile.v2 for where this file comes from.
if [ $(find serial -type f -name has_atomic_flag_lockfree \
		-print -quit | wc -l) -ne 0 ]; then
	DEF=D
else
	DEF=U
fi

m4 -${DEF}HAS_ATOMIC_FLAG_LOCKFREE -DVERSION=%{version} \
	%{SOURCE1} > $(basename %{SOURCE1})

# Build MPI parts of Boost with OpenMPI support

# N.B. python=2.* here behaves differently: it exactly selects a
# version that we want to build against.  Boost MPI is not portable to
# Python 3 due to API changes in Python, so this suits us.
%if %{with openmpi}

echo ============================= build $MPI_COMPILER ==================
./b2 -d+2 -q %{?_smp_mflags} \
	--with-mpi \
	--with-graph_parallel \
	--build-dir=$MPI_COMPILER \
	variant=release \
	threading=multi \
	debug-symbols=on \
	pch=off \
	python=%{python2_version} \
	stage
export PATH=/bin${PATH:+:}$PATH
%endif

# Build MPI parts of Boost with MPICH support
%if %{with mpich}
echo ============================= build $MPI_COMPILER ==================
./b2 -d+2 -q %{?_smp_mflags} \
	--with-mpi \
	--with-graph_parallel \
	--build-dir=$MPI_COMPILER \
	variant=release \
	threading=multi \
	debug-symbols=on \
	pch=off \
	python=%{python2_version} \
	stage
export PATH=/bin${PATH:+:}$PATH
%endif

echo ============================= build Boost.Build ==================
(cd tools/build
 ./bootstrap.sh --with-toolset=gcc)

%check
:

%install
rm -rf %{buildroot}
cd %{_builddir}/%{toplev_dirname}

%if %{with openmpi}
export MPI_HOME=%{_libdir}/openmpi
# XXX We want to extract this from RPM flags
# b2 instruction-set=i686 etc.
echo ============================= install $MPI_COMPILER ==================
./b2 -q %{?_smp_mflags} \
	--with-mpi \
	--with-graph_parallel \
	--build-dir=$MPI_COMPILER \
	--stagedir=%{buildroot}${MPI_HOME} \
	variant=release \
	threading=multi \
	debug-symbols=on \
	pch=off \
	python=%{python2_version} \
	stage

# Remove generic parts of boost that were built for dependencies.
rm -f %{buildroot}${MPI_HOME}/lib/libboost_{python,{w,}serialization}*

export PATH=/bin${PATH:+:}$PATH
%endif

%if %{with mpich}
export MPI_HOME=%{_libdir}/mpich
echo ============================= install $MPI_COMPILER ==================
./b2 -q %{?_smp_mflags} \
	--with-mpi \
	--with-graph_parallel \
	--build-dir=$MPI_COMPILER \
	--stagedir=%{buildroot}${MPI_HOME} \
	variant=release \
	threading=multi \
	debug-symbols=on \
	pch=off \
	python=%{python2_version} \
	stage

# Remove generic parts of boost that were built for dependencies.
rm -f %{buildroot}${MPI_HOME}/lib/libboost_{python,{w,}serialization}*
export PATH=/bin${PATH:+:}$PATH
%endif

echo ============================= install serial ==================
./b2 -d+2 -q %{?_smp_mflags} \
	--without-mpi \
	--without-graph_parallel \
	--build-dir=serial \
%if !%{with context}
	--without-context --without-coroutine \
%endif
	--prefix=%{buildroot}%{_prefix} \
	--libdir=%{buildroot}%{_libdir} \
	variant=release \
	threading=multi \
	debug-symbols=on \
	pch=off \
	python=%{python2_version} \
	install

# Override DSO symlink with a linker script.  See the linker script
# itself for details of why we need to do this.
[ -f %{buildroot}%{_libdir}/libboost_thread.so ] # Must be present
rm -f %{buildroot}%{_libdir}/libboost_thread.so
install -p -m 644 $(basename %{SOURCE1}) %{buildroot}%{_libdir}/

echo ============================= install Boost.Build ==================
(cd tools/build
 ./b2 --prefix=%{buildroot}%{_prefix} install
 # Fix some permissions
 chmod -x %{buildroot}%{_datadir}/boost-build/src/build/alias.py
 chmod +x %{buildroot}%{_datadir}/boost-build/src/tools/doxproc.py
 # We don't want to distribute this
 rm -f %{buildroot}%{_bindir}/b2
 # Not a real file
 rm -f %{buildroot}%{_datadir}/boost-build/src/build/project.ann.py
 # Empty file
 rm -f %{buildroot}%{_datadir}/boost-build/src/tools/doxygen/windows-paths-check.hpp
 # Install the manual page
 %{__install} -p -m 644 v2/doc/bjam.1 -D %{buildroot}%{_mandir}/man1/bjam.1
)

echo ============================= install Boost.QuickBook ==================
(cd tools/quickbook
 ../build/b2 --prefix=%{buildroot}%{_prefix}
 %{__install} -p -m 755 ../../dist/bin/quickbook %{buildroot}%{_bindir}/
 cd ../boostbook
 find dtd -type f -name '*.dtd' | while read tobeinstalledfiles; do
   install -p -m 644 $tobeinstalledfiles -D %{buildroot}%{_datadir}/boostbook/$tobeinstalledfiles
 done
 find xsl -type f | while read tobeinstalledfiles; do
   install -p -m 644 $tobeinstalledfiles -D %{buildroot}%{_datadir}/boostbook/$tobeinstalledfiles
 done
)

# Preparing the docs
mkdir packagedoc
find -type f -not -path '*packagedoc*' \( -name '*.html' -o -name '*.htm' -o -name '*.css' -o -name '*.gif' -o -name '*.jpg' -o -name '*.png' -o -name '*README*' \) -exec cp --parents {} packagedoc/ \;

# Preparing the examples: All .hpp or .cpp files that are not in
# directories called test, src, or tools, as well as all files of any
# type in directories called example or examples.
mkdir examples
find libs -type f \( -name "*.?pp" ! -path "*test*" ! -path "*src*" ! -path "*tools*" -o -path "*example*" \) -exec cp --parents {} examples/ \;

%post doctools
CATALOG=%{_sysconfdir}/xml/catalog
%{_bindir}/xmlcatalog --noout --add "rewriteSystem" \
 "http://www.boost.org/tools/boostbook/dtd" \
 "file://%{_datadir}/boostbook/dtd" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteURI" \
 "http://www.boost.org/tools/boostbook/dtd" \
 "file://%{_datadir}/boostbook/dtd" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteSystem" \
 "http://www.boost.org/tools/boostbook/xsl" \
 "file://%{_datadir}/boostbook/xsl" $CATALOG
%{_bindir}/xmlcatalog --noout --add "rewriteURI" \
 "http://www.boost.org/tools/boostbook/xsl" \
 "file://%{_datadir}/boostbook/xsl" $CATALOG

%postun doctools
# remove entries only on removal of package
if [ "$1" = 0 ]; then
  CATALOG=%{_sysconfdir}/xml/catalog
  %{_bindir}/xmlcatalog --noout --del \
    "file://%{_datadir}/boostbook/dtd" $CATALOG
  %{_bindir}/xmlcatalog --noout --del \
    "file://%{_datadir}/boostbook/xsl" $CATALOG
fi
   
%files -n %{libnamepy3}
%doc LICENSE_1_0.txt
%{_libdir}/libboost_python3.so.%{version}

%files devel-doc
%doc packagedoc/*

%files examples
%doc examples/*

%files -n %{devname}
%doc LICENSE_1_0.txt
%{_includedir}/%{name}
%{_libdir}/libboost_atomic.so
%{_libdir}/libboost_chrono.so
%{_libdir}/libboost_container.so
%if %{with context}
%{_libdir}/libboost_context.so
%{_libdir}/libboost_coroutine.so
%endif
%{_libdir}/libboost_date_time.so
%{_libdir}/libboost_filesystem.so
%{_libdir}/libboost_graph.so
%{_libdir}/libboost_iostreams.so
%{_libdir}/libboost_locale.so
%{_libdir}/libboost_log.so
%{_libdir}/libboost_log_setup.so
%{_libdir}/libboost_math_tr1.so
%{_libdir}/libboost_math_tr1f.so
%{_libdir}/libboost_math_tr1l.so
%{_libdir}/libboost_math_c99.so
%{_libdir}/libboost_math_c99f.so
%{_libdir}/libboost_math_c99l.so
%{_libdir}/libboost_prg_exec_monitor.so
%{_libdir}/libboost_unit_test_framework.so
%{_libdir}/libboost_program_options.so
%{_libdir}/libboost_python.so
%{_libdir}/libboost_python3.so
%{_libdir}/libboost_random.so
%{_libdir}/libboost_regex.so
%{_libdir}/libboost_serialization.so
%{_libdir}/libboost_type_erasure.so
%{_libdir}/libboost_wserialization.so
%{_libdir}/libboost_signals.so
%{_libdir}/libboost_system.so
%{_libdir}/libboost_thread.so
%{_libdir}/libboost_timer.so
%{_libdir}/libboost_wave.so

%files -n %{devnamestatic}
%doc LICENSE_1_0.txt
%{_libdir}/*.a
%if %{with mpich}
%{_libdir}/mpich/lib/*.a
%endif
%if %{with openmpi}
%{_libdir}/openmpi/lib/*.a
%endif

# OpenMPI packages
%if %{with openmpi}

%files -n %{libnamempi}
%doc LICENSE_1_0.txt
%{_libdir}/openmpi/lib/libboost_mpi.so.%{version}

%files -n %{devnamempi}
%doc LICENSE_1_0.txt
%{_libdir}/openmpi/lib/libboost_*.so

%files -n %{libnamempipy}
%doc LICENSE_1_0.txt
%{_libdir}/openmpi/lib/libboost_mpi_python.so.%{version}
%{_libdir}/openmpi/lib/mpi.so

%files -n %{libnamegraphmpi}
%doc LICENSE_1_0.txt
%{_libdir}/openmpi/lib/libboost_graph_parallel.so.%{version}

%endif

# MPICH packages
%if %{with mpich}

%files -n %{libnamempich}
%doc LICENSE_1_0.txt
%{_libdir}/mpich/lib/libboost_mpi.so.%{version}

%files -n %{devnamempich}
%doc LICENSE_1_0.txt
%{_libdir}/mpich/lib/libboost_*.so

%files -n %{libnamempichpy}
%doc LICENSE_1_0.txt
%{_libdir}/mpich/lib/libboost_mpi_python.so.%{version}
%{_libdir}/mpich/lib/mpi.so

%files -n %{libnamegraphmpich}
%doc LICENSE_1_0.txt
%{_libdir}/mpich/lib/libboost_graph_parallel.so.%{version}

%endif

%files build
%doc LICENSE_1_0.txt
%{_datadir}/boost-build/

%files doctools
%doc LICENSE_1_0.txt
%{_bindir}/quickbook
%{_datadir}/boostbook/

%files bjam
%doc LICENSE_1_0.txt
%{_bindir}/bjam
%{_mandir}/man1/bjam.1*


%changelog
* Wed Mar 15 2017 mrambo3501 <mrambo3501> 1.60.0-6.mga6
+ Revision: 1092684
- Rebuild for icu-58.2

* Fri Dec 02 2016 tmb <tmb> 1.60.0-5.mga6
+ Revision: 1071624
- rebuild for new openmpi

* Fri May 13 2016 shlomif <shlomif> 1.60.0-4.mga6
+ Revision: 1014876
- Rebuild for new ICU

* Sat Feb 13 2016 umeabot <umeabot> 1.60.0-3.mga6
+ Revision: 959623
- Mageia 6 Mass Rebuild

* Fri Jan 01 2016 luigiwalser <luigiwalser> 1.60.0-2.mga6
+ Revision: 917818
- rebuild for icu

* Thu Dec 24 2015 barjac <barjac> 1.60.0-1.mga6
+ Revision: 914081
- new version 1.60
- remove patches merged upstream and one not needed
- added one new lib in this version

* Wed Oct 07 2015 joequant <joequant> 1.59.0-8.mga6
+ Revision: 886679
- upgrade to python 3.5

* Wed Sep 30 2015 barjac <barjac> 1.59.0-7.mga6
+ Revision: 885236
- rebuild for openmpi-1.10.0

* Sat Sep 26 2015 barjac <barjac> 1.59.0-6.mga6
+ Revision: 883958
- correct rel on Conflicts and Obsoletes of thread_devel

* Sat Sep 26 2015 barjac <barjac> 1.59.0-5.mga6
+ Revision: 883947
- move thread_devel to main -devel
- move thread back into %%expand loop
- shorten some %%defines in line with others
- remove old Obsoletes that are no longer useful
- move devel(libboost_thread... Provide into main devel package

* Sat Sep 26 2015 daviddavid <daviddavid> 1.59.0-4.mga6
+ Revision: 883790
- fix again requires: replace character "-" to "_"

* Sat Sep 26 2015 fwang <fwang> 1.59.0-3.mga6
+ Revision: 883773
- fix requires

* Fri Sep 25 2015 barjac <barjac> 1.59.0-2.mga6
+ Revision: 883575
- add conflict in lib(64)boost_thread-devel sub pkg

* Thu Sep 24 2015 barjac <barjac> 1.59.0-1.mga6
+ Revision: 883345
- new version 1.59
- major overhaul adding mpi and mpich support
- now provides boost-bjam replacing separate pkg boost-jam
- conditional build for other arch including arm
- synced all Fedora patches
- split out thread from expand loop to allow fixing provides
- as thread now uses a link script
- added python3 support

  + blino <blino>
    - fix use of obsolete py_ver macro, use py2_ver

* Sat Aug 22 2015 akien <akien> 1.58.0-2.mga6
+ Revision: 868035
- Rebuild for gcc 5.2.1

* Wed Jul 29 2015 akien <akien> 1.58.0-1.mga6
+ Revision: 858955
- Dropped obsolete patches:
  o foreach patch is based on a commit that upstream reverted as it introduced new issues
  o long-double-1 patch was dropped by Fedora, and the initial bug report is fixed upstream
- Version 1.58.0
  o Adds "container" and removes "mpi" libraries
- Rediffed pool patch from upstream bug report

* Fri Jul 24 2015 cjw <cjw> 1.55.0-9.mga6
+ Revision: 856752
- rebuild for icu 55

* Thu Dec 04 2014 shlomif <shlomif> 1.55.0-8.mga5
+ Revision: 801527
- Fix MGA #14680 - put more static libs inside -static.

* Wed Oct 15 2014 umeabot <umeabot> 1.55.0-7.mga5
+ Revision: 750354
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.55.0-6.mga5
+ Revision: 725984
- rebuild for missing pythoneggs deps

* Thu Sep 18 2014 umeabot <umeabot> 1.55.0-5.mga5
+ Revision: 693513
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.55.0-4.mga5
+ Revision: 678201
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 philippem <philippem> 1.55.0-3.mga5
+ Revision: 632677
- rebuild for new Python 3.4

* Sat Apr 05 2014 wally <wally> 1.55.0-2.mga5
+ Revision: 611797
- rebuild for new icu

* Wed Feb 05 2014 barjac <barjac> 1.55.0-1.mga5
+ Revision: 582893
- new version 1.55
- enabled mpi
- removed patches applied upstream

* Sat Dec 14 2013 akien <akien> 1.54.0-8.mga4
+ Revision: 556764
- Add patch from upstream to fix int128 and uint128 conversions on i686 (boost#8790)

* Mon Oct 21 2013 umeabot <umeabot> 1.54.0-7.mga4
+ Revision: 539691
- Mageia 4 Mass Rebuild

* Mon Oct 07 2013 philippem <philippem> 1.54.0-6.mga4
+ Revision: 492789
- add python3

* Thu Sep 26 2013 fwang <fwang> 1.54.0-5.mga4
+ Revision: 486767
- rebuild for icu 52

* Wed Sep 18 2013 fwang <fwang> 1.54.0-4.mga4
+ Revision: 481116
- fix build with recent glibc

* Tue Jul 30 2013 fwang <fwang> 1.54.0-3.mga4
+ Revision: 461081
- add upstream promoted patches

* Tue Jul 09 2013 fwang <fwang> 1.54.0-2.mga4
+ Revision: 452091
- specify python lib
- fix usage of g++
- try always link with libstdc++ and libm

* Mon Jul 08 2013 fwang <fwang> 1.54.0-1.mga4
+ Revision: 451117
- add boost_log lib
- new version 1.54.0

* Sun May 26 2013 fwang <fwang> 1.53.0-2.mga4
+ Revision: 427911
- rebuild for new icu

* Mon Apr 08 2013 barjac <barjac> 1.53.0-1.mga3
+ Revision: 409132
- new version 1.53
- removed 3 patches incorporated upstream

* Sun Mar 24 2013 fwang <fwang> 1.52.0-4.mga3
+ Revision: 404853
- add upstream patch to fix locale security hole
- recall 1.52.0

* Thu Jan 31 2013 luigiwalser <luigiwalser> 1.52.0-3.mga3
+ Revision: 393832
- rebuild for icu

* Fri Jan 11 2013 umeabot <umeabot> 1.52.0-2.mga3
+ Revision: 347108
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 19 2012 kamil <kamil> 1.52.0-1.mga3
+ Revision: 332899
- rediff P9, partly merged upstream
- remove P2, merged upstream
- remove P0, 1_50_0 patch
- add new library: context
- new version 1.52.0

* Wed Nov 14 2012 shlomif <shlomif> 1.50.0-6.mga3
+ Revision: 317980
- Add the boost-build package (thanks to the Fedora .spec)

* Fri Nov 09 2012 fwang <fwang> 1.50.0-5.mga3
+ Revision: 316615
- rebuild for update icu

* Tue Nov 06 2012 fwang <fwang> 1.50.0-4.mga3
+ Revision: 314718
- rebuild for new icu

* Thu Aug 02 2012 fwang <fwang> 1.50.0-3.mga3
+ Revision: 277945
- build mt flavour

* Thu Aug 02 2012 fwang <fwang> 1.50.0-2.mga3
+ Revision: 277937
- add include dir
- build force with python and icu

* Tue Jul 31 2012 fwang <fwang> 1.50.0-1.mga3
+ Revision: 276486
- sync with fedora packages

  + kamil <kamil>
    - new version 1.50.0
    - drop P3 - merged upstream

* Fri Jun 29 2012 luigiwalser <luigiwalser> 1.49.0-3.mga3
+ Revision: 264808
- add patch from fedora to fix CVE-2012-2677

* Tue May 29 2012 fwang <fwang> 1.49.0-2.mga3
+ Revision: 248942
- rebuild for new icu

* Mon May 28 2012 kamil <kamil> 1.49.0-1.mga3
+ Revision: 247830
- new version 1.49.0
- drop boost-1.48.0-fix-boost-foreach.patch (merged upstream)

* Sun Apr 22 2012 mitya <mitya> 1.48.0-9.mga2
+ Revision: 232493
- Sync with Fedora; introduce Boost.Timer and Boost.Math

* Tue Jan 17 2012 mikala <mikala> 1.48.0-8.mga2
+ Revision: 197109
- Remove all cmake files :
 - a needed file was already removed since the cmake switch
 - according to https://bugzilla.redhat.com/show_bug.cgi?id=597020 boost detection for cmake is just broken
 - this allow us to drop a patch from cmake restoring an old detection stuff

* Sun Dec 04 2011 fwang <fwang> 1.48.0-7.mga2
+ Revision: 175899
- drop more arch-dependent tags from noarch packages

* Sun Dec 04 2011 fwang <fwang> 1.48.0-6.mga2
+ Revision: 175889
- obsoletes doc package in all arch

* Tue Nov 29 2011 fwang <fwang> 1.48.0-5.mga2
+ Revision: 174067
- add upstream patch to fix foreach defination
- fix obsoletes
- should be noarch package

* Sun Nov 27 2011 fwang <fwang> 1.48.0-3.mga2
+ Revision: 173002
- fix typo
- unify doc package name in all arch

* Sun Nov 27 2011 fwang <fwang> 1.48.0-1.mga2
+ Revision: 172780
- add locale sub package
- more fix on cmake patch
- manually set icu flags
- new version 1.48.0

* Sun Sep 25 2011 anssi <anssi> 1.47.0-2.mga2
+ Revision: 147568
- add compatibility symlinks for .so devel symlinks and static libraries
  (cmakeify-full.patch adds an extra '-mt' into the library names which
  the libraries built with the upstream bjam build system (with
  --layout=system) don't have)

  + fwang <fwang>
    - update lib list
    - depends boost_system
    - new version 1.47.0

* Mon Jun 20 2011 fwang <fwang> 1.46.1-1.mga2
+ Revision: 110264
- sync patches
- New version 1.46.1
- synch with fedora (cmake flavour)

  + rtp <rtp>
    - fix bootlibs macro on arm/mips

* Tue Jan 18 2011 pterjan <pterjan> 1.44.0-6.mga1
+ Revision: 21821
- Rebuild for python 2.7

* Sat Jan 08 2011 blino <blino> 1.44.0-5.mga1
+ Revision: 1220
- remove old ldconfig scriptlets
- imported package boost


* Tue Nov 02 2010 Crispin Boylan <crisb@mandriva.org> 1.44.0-4mdv2011.0
+ Revision: 592080
- Patch 1 to fix boost issue #4598

* Fri Oct 29 2010 Funda Wang <fwang@mandriva.org> 1.44.0-3mdv2011.0
+ Revision: 590114
- rebuild for new python

* Thu Sep 02 2010 Thierry Vignaud <tv@mandriva.org> 1.44.0-2mdv2011.0
+ Revision: 575199
- let the doc subpackage be noarch

* Sun Aug 22 2010 Emmanuel Andry <eandry@mandriva.org> 1.44.0-1mdv2011.0
+ Revision: 572035
- New version 1.44.0

* Wed Aug 04 2010 Funda Wang <fwang@mandriva.org> 1.43.0-2mdv2011.0
+ Revision: 565900
- patch1 not needed

  + Luis Medinas <lmedinas@mandriva.org>
    - Fix static-devel symlinks.

  + Matthew Dawkins <mattydaw@mandriva.org>
    - new version 1.43.0
      added random to pkgs list

* Sun Mar 21 2010 Funda Wang <fwang@mandriva.org> 1.42.0-3mdv2010.1
+ Revision: 526045
- rebuild for new icu

* Tue Feb 23 2010 Crispin Boylan <crisb@mandriva.org> 1.42.0-2mdv2010.1
+ Revision: 509861
- Add serialization patch from svn fixes crash on exit when using dlopen libs

  + Anssi Hannula <anssi@mandriva.org>
    - rebuild for new boost

* Mon Feb 08 2010 Anssi Hannula <anssi@mandriva.org> 1.42.0-1mdv2010.1
+ Revision: 501872
- new version
- conditionally bring back support for building with bjam (there is no
  cmake-enabled version of 1.42.0 available)
- drop patches applied upstream (mapnik.patch, fix-serialization.patch)
- build only multithreaded versions of the libraries
- split the libraries into their own subpackages to minimize installation
  footprint on user systems

* Thu Feb 04 2010 Jérôme Brenier <incubusss@mandriva.org> 1.41.0-3mdv2010.1
+ Revision: 501005
- add one patch to fix serialization to build easystroke (from upstream)

* Wed Feb 03 2010 Funda Wang <fwang@mandriva.org> 1.41.0-2mdv2010.1
+ Revision: 500157
- add fedora patch to satisfy mapnik build

* Wed Feb 03 2010 Funda Wang <fwang@mandriva.org> 1.41.0-1mdv2010.1
+ Revision: 499854
- BR xsltproc
- New version 1.41.0 (cmake build based)
- drop all build patches as cmake can deal with all things :D
- revert to SONAME=VERSION, keep same with Fedora :(

  + Olivier Blin <oblin@mandriva.com>
    - simplify long-double check
    - fix build on ARM and MIPS, they don't really have long double (from Arnaud Patard)

* Thu Aug 20 2009 Helio Chissini de Castro <helio@mandriva.com> 1.39.0-2mdv2010.0
+ Revision: 418718
- Added patch to fix pyside compilation. This is included in boost-to-be 1.4.0 official near release

* Sat Aug 15 2009 Emmanuel Andry <eandry@mandriva.org> 1.39.0-1mdv2010.0
+ Revision: 416502
- disable BR openmpi-devel, as it's not welcome in main

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - build with graphml support
    - build with mpi support
    - fix file permissions for -devel package
    - replace patch that sets %%optflags with a new one that takes an environment
      variable in stead (P0)
    - set same ABI major as Fedora and provide compatibility symlinks for "old"
      soname fashion. This should hopefully help decrease the amount of packages
      linked against older library versions (P1)
    - sync with some fedora patches
    - new release: 1.39.0

* Mon Mar 02 2009 Emmanuel Andry <eandry@mandriva.org> 1.38.0-2mdv2009.1
+ Revision: 346986
- New version 1.38.0
- drop P5 (merged upstream)

* Fri Jan 16 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.37.0-4mdv2009.1
+ Revision: 330353
- Patch6: fix wrong BOOST_NO_EXCEPTIONS define placement (upstream bug #2469)

* Fri Dec 26 2008 Funda Wang <fwang@mandriva.org> 1.37.0-3mdv2009.1
+ Revision: 319262
- link with libpython

* Tue Dec 23 2008 Funda Wang <fwang@mandriva.org> 1.37.0-2mdv2009.1
+ Revision: 317920
- use correct license

* Sat Dec 20 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.37.0-1mdv2009.1
+ Revision: 316499
- use _disable_ld_no_undefined 1 (lof of python stuff)
- Patch2: rediff
- don't export optflags, better to sed them in
- use %%ldflags
- update to new version 1.37.0

* Mon Aug 18 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.36.0-1mdv2009.0
+ Revision: 273337
- new release
- drop P6 (merged upstream)
- compile with -O3

* Mon Jul 14 2008 Oden Eriksson <oeriksson@mandriva.com> 1.35.0-3mdv2009.0
+ Revision: 234634
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu May 29 2008 David Walluck <walluck@mandriva.org> 1.35.0-2mdv2009.0
+ Revision: 212839
- patch for gcc 4.3 serialization fix
- patch for gcc 4.3 date_time fix

* Tue May 20 2008 Oden Eriksson <oeriksson@mandriva.com> 1.35.0-1mdv2009.0
+ Revision: 209510
- 1.35.0
- rediffed the patches
- drop upstream implemented patches (CVE-2008-0171+0172 is applied)
- fix the find logig (thanks anssi)

* Tue May 20 2008 Oden Eriksson <oeriksson@mandriva.com> 1.34.1-5mdv2009.0
+ Revision: 209434
- added P5 from fedora (gcc43 patch)

* Sat Feb 09 2008 Anssi Hannula <anssi@mandriva.org> 1.34.1-4mdv2008.1
+ Revision: 164328
- fix CVE-2008-0171 and CVE-2008-0172 (P0, #37412)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Nov 30 2007 Anssi Hannula <anssi@mandriva.org> 1.34.1-3mdv2008.1
+ Revision: 114034
- provide libboost_thread.so devel symlink for compatibility

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - add more explicit provides for devel pkg

* Thu Nov 01 2007 Anssi Hannula <anssi@mandriva.org> 1.34.1-2mdv2008.1
+ Revision: 104690
- use version as major as per upstream and debian
- remove boost-configure.patch, modifies irrelevant file
- remove boost-gcc-soname.patch, did not work as intended and is now
  unnecessary
- use --layout=system to drop gcc version from soname and remove the
  need for manual include move hack
- add patch from boost ml to include version in library name with
  --layout=system (boost-layout-system.patch)
- build with libicu
- drop obsolete hacks and comments
- use proper bjam flags (build single- and multi-threaded versions,
  release variants only, parallel build)
- ensure major correctness in filelist

* Tue Sep 04 2007 David Walluck <walluck@mandriva.org> 1.34.1-1mdv2008.1
+ Revision: 78984
- 1.34.1
- new lib policy
- rename examples subpackage
- take patches from Fedora

* Fri Jul 06 2007 Adam Williamson <awilliamson@mandriva.org> 1.33.1-6mdv2008.0
+ Revision: 49245
- add patch6 (atomicity.h has moved in recent GCC)


* Sat Jan 13 2007 Anssi Hannula <anssi@mandriva.org> 1.33.1-5mdv2007.0
+ Revision: 108182
- fix build with python2.5 (patch5, from cvs)

* Fri Oct 13 2006 Nicolas Lécureuil <neoclust@mandriva.org> 1.33.1-4mdv2007.1
+ Revision: 63856
- Add patch
- Add missing include
- import boost-1.33.1-3mdv2007.0

* Fri Jul 28 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 1.33.1-3
- add BuildRequires: libz-devel

* Sun Apr 30 2006 David Walluck <walluck@mandriva.org> 1.33.1-2mdk
- adding missing BuildRequires: libbzip2-devel
- adding missing BuildRequires: libpython-devel
- add lib64boost Provides as per rpmlint

* Fri Apr 21 2006 Per yvind Karlsen <pkarlsen@mandriva.com> 1.33.1-1mdk
- 1.33.1
- drop P1 & P3 (fixed upstream)

* Tue Jan 03 2006 Stefan van der Eijk <stefan@eijk.nu> 1.32.0-5mdk
- rebuild

* Thu Jul 07 2005 Per yvind Karlsen <pkarlsen@mandriva.com> 1.32.0-4mdk
- make gcc4 a known compiler (P3, fixes #16719)

* Wed May 04 2005 Per yvind Karlsen <pkarlsen@mandriva.com> 1.32.0-3mdk
- lib64 fixes
- %%{1}mdv2007.1

* Wed Mar 23 2005 Per yvind Karlsen <peroyvind@linux-mandrake.com> 1.32.0-2mdk
- multiarch
- fix summary-ended-with-dot

* Wed Dec 08 2004 Michael Scherer <misc@mandrake.org> 1.32.0-1mdk
- 1.32.0

* Tue Jul 06 2004 Michael Scherer <misc@mandrake.org> 1.31.0-5mdk 
- rebuild for new gcc, reenable python support

* Tue Jun 08 2004 Michael Scherer <misc@mandrake.org> 1.31.0-4mdk 
- rebuild for new gcc
- remove python support, doesn't build at the moment

* Sun May 30 2004 Abel Cheung <deaddog@deaddog.org> 1.31.0-3mdk
- P1-2: Use fedora patches (thanks for Nick Brown's help
  nicbrown <AT> cisco.com), to avoid appending compiler/variant
  name into library, other softwares don't want that (#9648)
- Only build threaded libraries, remove debug package

* Fri Apr 30 2004 Abel Cheung <deaddog@deaddog.org> 1.31.0-2mdk
- Reenable patch1 (peroyvind, would you please NOT randomly disable
  patches AND without indicating it in changelog?)
- Redo part of spec to fix f*cked up installation (#9648)
- If one wants debug build, toggle it in ~/.rpmmacros instead of doing it here

* Wed Feb 04 2004 Per yvind Karlsen <peroyvind@linux-mandrake.com> 1.31.0-1mdk
- 1.31.0

